# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main_window.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(767, 454)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.btn_create = QtWidgets.QPushButton(self.centralwidget)
        self.btn_create.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.btn_create.setObjectName("btn_create")
        self.gridLayout.addWidget(self.btn_create, 1, 1, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btn_add_clip = QtWidgets.QPushButton(self.centralwidget)
        self.btn_add_clip.setObjectName("btn_add_clip")
        self.horizontalLayout.addWidget(self.btn_add_clip)
        self.btn_delete_clip = QtWidgets.QPushButton(self.centralwidget)
        self.btn_delete_clip.setObjectName("btn_delete_clip")
        self.horizontalLayout.addWidget(self.btn_delete_clip)
        self.gridLayout.addLayout(self.horizontalLayout, 1, 0, 1, 1)
        self.clip_view = ClipListView(self.centralwidget)
        self.clip_view.setLineWidth(1)
        self.clip_view.setObjectName("clip_view")
        self.gridLayout.addWidget(self.clip_view, 0, 0, 1, 1)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.btn_move_up = QtWidgets.QPushButton(self.centralwidget)
        self.btn_move_up.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.btn_move_up.setObjectName("btn_move_up")
        self.verticalLayout_2.addWidget(self.btn_move_up)
        self.btn_move_down = QtWidgets.QPushButton(self.centralwidget)
        self.btn_move_down.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.btn_move_down.setObjectName("btn_move_down")
        self.verticalLayout_2.addWidget(self.btn_move_down)
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.lbl_song_length = QtWidgets.QLabel(self.centralwidget)
        self.lbl_song_length.setObjectName("lbl_song_length")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.lbl_song_length)
        self.txt_song_length = QtWidgets.QLineEdit(self.centralwidget)
        self.txt_song_length.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.txt_song_length.setObjectName("txt_song_length")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.txt_song_length)
        self.lbl_voice_start = QtWidgets.QLabel(self.centralwidget)
        self.lbl_voice_start.setObjectName("lbl_voice_start")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.lbl_voice_start)
        self.txt_voice_start = QtWidgets.QLineEdit(self.centralwidget)
        self.txt_voice_start.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.txt_voice_start.setObjectName("txt_voice_start")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.txt_voice_start)
        self.lbl_voice_end = QtWidgets.QLabel(self.centralwidget)
        self.lbl_voice_end.setObjectName("lbl_voice_end")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.lbl_voice_end)
        self.txt_voice_end = QtWidgets.QLineEdit(self.centralwidget)
        self.txt_voice_end.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.txt_voice_end.setObjectName("txt_voice_end")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.txt_voice_end)
        self.verticalLayout_2.addLayout(self.formLayout)
        self.gridLayout.addLayout(self.verticalLayout_2, 0, 1, 1, 1)
        self.gridLayout.setColumnStretch(0, 1)
        self.gridLayout.setRowStretch(1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 767, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.act_new = QtWidgets.QAction(MainWindow)
        self.act_new.setObjectName("act_new")
        self.act_create_clip = QtWidgets.QAction(MainWindow)
        self.act_create_clip.setObjectName("act_create_clip")
        self.act_exit = QtWidgets.QAction(MainWindow)
        self.act_exit.setObjectName("act_exit")
        self.act_add_clip = QtWidgets.QAction(MainWindow)
        self.act_add_clip.setObjectName("act_add_clip")
        self.act_delete_clip = QtWidgets.QAction(MainWindow)
        self.act_delete_clip.setObjectName("act_delete_clip")
        self.act_help = QtWidgets.QAction(MainWindow)
        self.act_help.setObjectName("act_help")
        self.act_about = QtWidgets.QAction(MainWindow)
        self.act_about.setObjectName("act_about")
        self.menuFile.addAction(self.act_new)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.act_create_clip)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.act_exit)
        self.menuEdit.addAction(self.act_add_clip)
        self.menuEdit.addAction(self.act_delete_clip)
        self.menuHelp.addAction(self.act_help)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.act_about)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Top 30 Creator"))
        self.btn_create.setText(_translate("MainWindow", "Create"))
        self.btn_add_clip.setText(_translate("MainWindow", "Add Clip"))
        self.btn_delete_clip.setText(_translate("MainWindow", "Delete Clip"))
        self.btn_move_up.setText(_translate("MainWindow", "Move Up"))
        self.btn_move_down.setText(_translate("MainWindow", "Move Down"))
        self.lbl_song_length.setText(_translate("MainWindow", "Song Length:"))
        self.lbl_voice_start.setText(_translate("MainWindow", "Voice Start Overlap:"))
        self.lbl_voice_end.setText(_translate("MainWindow", "Voice End Overlap:"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuEdit.setTitle(_translate("MainWindow", "Edit"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.act_new.setText(_translate("MainWindow", "New"))
        self.act_create_clip.setText(_translate("MainWindow", "Create"))
        self.act_exit.setText(_translate("MainWindow", "Exit"))
        self.act_add_clip.setText(_translate("MainWindow", "Add Clip..."))
        self.act_delete_clip.setText(_translate("MainWindow", "Delete Clip.."))
        self.act_help.setText(_translate("MainWindow", "Top 30 Creator Help"))
        self.act_about.setText(_translate("MainWindow", "About"))

from top30.clip_list import ClipListView
